==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/PasswordPolicyRecoveryEmail.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LifecycleStatus;
import com.okta.sdk.resource.model.PasswordPolicyRecoveryEmailProperties;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordPolicyRecoveryEmail
 */
@JsonPropertyOrder({ PasswordPolicyRecoveryEmail.JSON_PROPERTY_PROPERTIES,
        PasswordPolicyRecoveryEmail.JSON_PROPERTY_STATUS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PasswordPolicyRecoveryEmail implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PROPERTIES = "properties";
    private PasswordPolicyRecoveryEmailProperties properties;

    public static final String JSON_PROPERTY_STATUS = "status";
    private LifecycleStatus status;

    public PasswordPolicyRecoveryEmail() {
    }

    public PasswordPolicyRecoveryEmail properties(PasswordPolicyRecoveryEmailProperties properties) {

        this.properties = properties;
        return this;
    }

    /**
     * Get properties
     *
     * @return properties
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PROPERTIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryEmailProperties getProperties() {
        return properties;
    }

    @JsonProperty(JSON_PROPERTY_PROPERTIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProperties(PasswordPolicyRecoveryEmailProperties properties) {
        this.properties = properties;
    }

    public PasswordPolicyRecoveryEmail status(LifecycleStatus status) {

        this.status = status;
        return this;
    }

    /**
     * Get status
     *
     * @return status
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LifecycleStatus getStatus() {
        return status;
    }

    @JsonProperty(JSON_PROPERTY_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setStatus(LifecycleStatus status) {
        this.status = status;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordPolicyRecoveryEmail passwordPolicyRecoveryEmail = (PasswordPolicyRecoveryEmail) o;
        return Objects.equals(this.properties, passwordPolicyRecoveryEmail.properties)
                && Objects.equals(this.status, passwordPolicyRecoveryEmail.status);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(properties, status);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordPolicyRecoveryEmail {\n");
        sb.append("    properties: ").append(toIndentedString(properties)).append("\n");
        sb.append("    status: ").append(toIndentedString(status)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/PasswordPolicyRecoveryEmail.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LifecycleStatus;
import com.okta.sdk.resource.model.PasswordPolicyRecoveryEmailProperties;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordPolicyRecoveryEmail
 */
@JsonPropertyOrder({ PasswordPolicyRecoveryEmail.JSON_PROPERTY_PROPERTIES,
        PasswordPolicyRecoveryEmail.JSON_PROPERTY_STATUS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class PasswordPolicyRecoveryEmail implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PROPERTIES = "properties";
    private PasswordPolicyRecoveryEmailProperties properties;

    public static final String JSON_PROPERTY_STATUS = "status";
    private LifecycleStatus status;

    public PasswordPolicyRecoveryEmail() {
    }

    public PasswordPolicyRecoveryEmail properties(PasswordPolicyRecoveryEmailProperties properties) {

        this.properties = properties;
        return this;
    }

    /**
     * Get properties
     *
     * @return properties
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PROPERTIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryEmailProperties getProperties() {
        return properties;
    }

    @JsonProperty(JSON_PROPERTY_PROPERTIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProperties(PasswordPolicyRecoveryEmailProperties properties) {
        this.properties = properties;
    }

    public PasswordPolicyRecoveryEmail status(LifecycleStatus status) {

        this.status = status;
        return this;
    }

    /**
     * Get status
     *
     * @return status
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LifecycleStatus getStatus() {
        return status;
    }

    @JsonProperty(JSON_PROPERTY_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setStatus(LifecycleStatus status) {
        this.status = status;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordPolicyRecoveryEmail passwordPolicyRecoveryEmail = (PasswordPolicyRecoveryEmail) o;
        return Objects.equals(this.properties, passwordPolicyRecoveryEmail.properties)
                && Objects.equals(this.status, passwordPolicyRecoveryEmail.status);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(properties, status);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordPolicyRecoveryEmail {\n");
        sb.append("    properties: ").append(toIndentedString(properties)).append("\n");
        sb.append("    status: ").append(toIndentedString(status)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
